Documentation
¶
Overview ¶
Package fssdk is the Function Stream Go SDK for WASM processors. Implement Driver (or embed BaseDriver) and call Run(driver).
Index ¶
Constants ¶
const ( ErrRuntimeInvalidDriver = api.ErrRuntimeInvalidDriver ErrRuntimeNotInitialized = api.ErrRuntimeNotInitialized ErrRuntimeClosed = api.ErrRuntimeClosed ErrStoreInvalidName = api.ErrStoreInvalidName ErrStoreInternal = api.ErrStoreInternal ErrStoreNotFound = api.ErrStoreNotFound ErrStoreIO = api.ErrStoreIO ErrResultUnexpected = api.ErrResultUnexpected )
Re-export error codes.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BaseDriver ¶
type BaseDriver = api.BaseDriver
Re-export API types and errors so existing code keeps using fssdk.*.
type ComplexKey ¶
type ComplexKey = api.ComplexKey
Re-export API types and errors so existing code keeps using fssdk.*.
Click to show internal directories.
Click to hide internal directories.